@@ -57,14 +57,14 @@ PartPropsDialog::PartPropsDialog(QWidget* parent, Device& d, Partition& p) :
     setupDialog();
     setupConnections();
 
-    KConfigGroup kcg(KSharedConfig::openConfig(), "partPropsDialog");
+    KConfigGroup kcg(KSharedConfig::openConfig(), QStringLiteral("partPropsDialog"));
     restoreGeometry(kcg.readEntry<QByteArray>("Geometry", QByteArray()));
 }
 
 /** Destroys a PartPropsDialog */
 PartPropsDialog::~PartPropsDialog()
 {
-    KConfigGroup kcg(KSharedConfig::openConfig(), "partPropsDialog");
+    KConfigGroup kcg(KSharedConfig::openConfig(), QStringLiteral("partPropsDialog"));
     kcg.writeEntry("Geometry", saveGeometry());
 }
 
@@ -264,7 +264,7 @@ void PartPropsDialog::updateHideAndShow()
 void PartPropsDialog::setupConnections()
 {
     connect(&dialogWidget().label(), &QLineEdit::textEdited, [this] (const QString &) {setDirty();});
-    connect(&dialogWidget().fileSystem(), qOverload<int>(&QComboBox::currentIndexChanged), this, &PartPropsDialog::onFilesystemChanged);
+    connect(&dialogWidget().fileSystem(), &QComboBox::currentIndexChanged, this, &PartPropsDialog::onFilesystemChanged);
     connect(&dialogWidget().checkRecreate(), &QCheckBox::stateChanged, this, &PartPropsDialog::onRecreate);
 
     // We want to enable the OK-button whenever the user checks or unchecks a flag in the flag list.
@@ -359,7 +359,7 @@ void PartPropsDialog::onFilesystemChanged(int)
     } else {
         dialogWidget().fileSystem().disconnect(this);
         setupFileSystemComboBox();
-        connect(&dialogWidget().fileSystem(), qOverload<int>(&QComboBox::currentIndexChanged), this, &PartPropsDialog::onFilesystemChanged);
+        connect(&dialogWidget().fileSystem(), &QComboBox::currentIndexChanged, this, &PartPropsDialog::onFilesystemChanged);
     }
 }
 
